@@ -134,11 +134,11 @@ const MainWindow = new Lang.Class({
 
     _createSidebar: function() {
         let sidebar = new Sidebar.Sidebar(this._mapView);
-        Application.routeService.query.connect('notify',
-                                               this._setRevealSidebar.bind(this, true));
 
+        Application.routeQuery.connect('notify',
+                                       this._setRevealSidebar.bind(this, true));
         this._toggleSidebarButton.bind_property('active',
-                                                this._mapView, 'routeVisible',
+                                                this._mapView, 'routingOpen',
                                                 GObject.BindingFlags.BIDIRECTIONAL);
         this.application.bind_property('connected',
                                        sidebar, 'visible',
@@ -276,7 +276,7 @@ const MainWindow = new Lang.Class({
             this._favoritesButton.sensitive = favoritesPopover.rows > 0;
         }).bind(this));
 
-        this._mapView.bind_property('routeVisible', this._printRouteButton,
+        this._mapView.bind_property('routeShowing', this._printRouteButton,
                                     'visible', GObject.BindingFlags.DEFAULT);
 
         Application.geoclue.connect('notify::state',
@@ -401,7 +401,7 @@ const MainWindow = new Lang.Class({
     },
 
     _printRouteActivate: function() {
-        if (this._mapView.routeVisible) {
+        if (this._mapView.routeShowing) {
             let operation = new PrintOperation.PrintOperation({ mainWindow: this });
         }
     },
